@@ -4,8 +4,8 @@ use strict;
 use warnings;
 use Getopt::Long;
 
-# use FindBin;
-# use lib "$FindBin::Bin/../lib";
+use FindBin;
+use lib "$FindBin::Bin/../lib";
 use ANSI::Unicode;
 
 #
